package VMOMI::EventCategory;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
